/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.spray;

import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.task.Task;
import nl.cloudfarming.client.task.button.ItemSelectButton;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle.Messages;

/**
 * This button can be used to produce treatmentzones for the active task. 
 * It uses the actionPerformed of the ItemSelectButton superclass to search 
 * for TaskObjectFactories able to produce treatmentzones for the active task in the lookup.
 * - If one is found, that one will be started
 * - If more then one is found the user will be presented a selection windows to select the source of treatmentzones. 
 * The correct wizard is started after the user clicks finish.
 * 
 * Usage: Create an instance of this button and add it to your panel.
 * 
 * Creation of new selectionbutton: Create necessary taskobjectfactory(s), copy this class, adjust static variables to suit your needs.
 * 
 * @author Gerben Feenstra
 */

@Messages({
    "TreatmentZoneSelectButton_toolTipText=Click to add treatment zone",
    "TreatmentZoneSelectButton_text=Treatmentzone",
    "TreatmentZoneSelectButton_wizard_panel_title=Select treatmentzone source",
    "TreatmentZoneSelectButton_wizard_panel_text=Select the source for treatmentzones. The wizard will convert the selected item(s) to treatmentzone(s).",

})
public class TreatmentZoneSelectButton extends ItemSelectButton {
    
    private static final String PANEL_TITLE = Bundle.TreatmentZoneSelectButton_wizard_panel_title();
    private static final String PANEL_TEXT = Bundle.TreatmentZoneSelectButton_wizard_panel_text();
    private static final String BUTTON_ICON = "nl/cloudfarming/client/field/type/buttons/treatmentzone32.png";
    private static final String BUTTON_TITLE = Bundle.TreatmentZoneSelectButton_text();
    private static final String BUTTON_TOOLTIP = Bundle.TreatmentZoneSelectButton_toolTipText();
    private static final Class TO_SELECT = TreatmentZone.class;
    
    private int selectionMode;      
    
    /**
     * Register this button as listeners of itself so that actionPerformed is called when the button is clicked.
     */
    public TreatmentZoneSelectButton(Task task, int selectionMode){
        super(task, TO_SELECT);
        this.selectionMode = selectionMode;
        // Treatmentzone specific settings select button
        setIcon(ImageUtilities.loadImageIcon(BUTTON_ICON, false));
        setText(BUTTON_TITLE); // Standard = showButtonText, disable by calling showButtonText(false);
        setToolTipText(BUTTON_TOOLTIP);
    }

    @Override
    public String getPanelTitle() {
        return PANEL_TITLE;
    }

    @Override
    public String getPanelText() {
        return PANEL_TEXT;
    }

    @Override
    public String getButtonText() {
        return BUTTON_TITLE;
    }

    @Override
    public int getSelectionMode() {
        return selectionMode;
    }
}
